pub trait FromBoxedFrameSlice<F>where
F: Frame,{
// Required method
fn from_boxed_frame_slice(slice: Box<[F]>) -> Self;
}Expand description
For converting from a boxed slice of Frames to a boxed slice of Samples.
Required Features
- When using
dasp_slice, this item requires the boxed feature to be enabled. - When using
dasp, this item requires the slice-boxed feature to be enabled.
Required Methods
fn from_boxed_frame_slice(slice: Box<[F]>) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.